@@ -13,6 +13,7 @@ class Building(object):
 
         self.jeopardy = False
         self.jeopardy_count = 0
+        self.player_taking_over = None
 
         self.tile = tile
         self.region = self.tile.region
@@ -52,6 +53,12 @@ class Building(object):
             if self.jeopardy:
                 bisect.insort(data.draw_buffer, data.Rendered(
                     data.jeopardy_marker, x+self.size*32-32, marker_y, z=4))
+
+                # Draw time left before takeover.
+                data.stat_font.render(x, y, "Takeover: %i" %\
+                        ((self.jeopardy_count+self.takeover_time-\
+                        data.get_ticks())//1000),
+                        self.player_taking_over.glcolor)
             else:
                 bisect.insort(data.draw_buffer, data.Rendered(data.marker,
                     x+self.size*32-32, marker_y, colorize=self.player.glcolor,
@@ -62,9 +69,7 @@ class Building(object):
                 for k,v in self._storage.items():
                     if v:
                         s.append(k+": "+str(v))
-                glColor3f(0,0,0)
-                data.stat_font.glPrint(x, marker_y+25, "  ".join(s))
-                glColor3f(1,1,1)
+                data.stat_font.render(x, marker_y+25, "  ".join(s), (0,0,0))
 
 
     def _set_player(self, player):
