@@ -9,13 +9,15 @@ class Igloo(Building):
     image_name = "igloo"
     smoke_start = (101,30)
 
+    # in milliseconds.
+    takeover_time = 30000
 
 
     def in_building(self, unit):
         # FIXME: this does NOT support multiple enemies in an igloo!
         if self.jeopardy:
             if unit.player != self.player:
-                if self.jeopardy_count+30000 <= data.get_ticks():
+                if self.jeopardy_count+self.takeover_time <= data.get_ticks():
                     # Takeover!
                     self.region.player = unit.player
                     self.jeopardy = False
@@ -46,6 +48,7 @@ class Igloo(Building):
 
     def unit_enter(self, unit):
         if unit.player != self.player:
+            self.player_taking_over = unit.player
             self.jeopardy = True
             self.jeopardy_count = data.get_ticks()
 
