@@ -7,6 +7,11 @@ import unit
 import selectctrl
 
 
+nums = {K_1:1, K_2:2, K_3:3, K_4:4, K_5:5, K_6:6, K_7:7, K_8:8, K_9:9}
+groups = {1:set(), 2:set(), 3:set(), 4:set(), 5:set(), 6:set(), 7:set(),
+        8:set(), 9:set(), }
+
+
 def get_scale_mouse_pos():
     p = list(pygame.mouse.get_pos())
     p[0] /= data.view.zoom
@@ -39,7 +44,16 @@ def start_select((x,y)):
 
 def end_select():
     mods = pygame.key.get_mods()
-    if not KMOD_LSHIFT == mods and not KMOD_RSHIFT == mods:
+    ctrl_pressed = False
+    shift_pressed = False
+    # Shift overrules Ctrl
+    if (KMOD_LSHIFT | KMOD_RSHIFT) & mods:
+        shift_pressed = True
+    elif (KMOD_LCTRL | KMOD_RCTRL) & mods:
+        ctrl_pressed = True
+    # Forget previous selection if neither of the group selection modifiers
+    # are pressed.
+    if not (shift_pressed or ctrl_pressed):
         for u in data.selected_units:
             u.selected = False
         data.selected_units = set()
@@ -59,8 +73,12 @@ def end_select():
         cx,cy = u.penguin_sprite.xy
         if cx+32 > start_x and cx < end_x and cy+32 > start_y and cy < end_y:
             if u.igloo.player == data.player:
-                data.selected_units.add(u)
-                u.selected = True
+                if ctrl_pressed and u in data.selected_units:
+                    data.selected_units.remove(u)
+                    u.selected = False
+                else:
+                    data.selected_units.add(u)
+                    u.selected = True
 
     data.select_box_start = data.select_box_end = None
 
@@ -107,6 +125,7 @@ def disban_units():
 def scroll_screen((x,y), dt):
     speed = 50
     speed = (dt/speed)*32
+    speed = speed*(2-data.view.zoom)
     if x < 10:
         data.view.x -= speed
     elif x > data.view.w-10:
@@ -131,17 +150,20 @@ def scroll_screen((x,y), dt):
 
 def look_at(x, y):
     """
-    Center the screen on the given x,y tile coordinates.
+    Center the screen on the given x,y coordinates.
     """
-    data.view.x, data.view.y = x*32 - data.view.w//2, y*32 - data.view.h//2
+    data.view.x, data.view.y = x - data.view.scale_w//2, y - data.view.scale_h//2
     bind_screen()
 
 def bind_screen():
     """
     Make sure that the screen is within the map bounds.
     """
-    data.view.x = max(0, min(data.map.size[0]*32-data.view.scale_w, data.view.x))
-    data.view.y = max(0, min(data.map.size[1]*32-data.view.scale_h, data.view.y))
+    if data.view.zoom == 1:
+    #if data.view.scale_w < data.map.size[0]*32:
+        data.view.x = max(0, min(data.map.size[0]*32-data.view.scale_w, data.view.x))
+    #if data.view.scale_h < data.map.size[1]*32:
+        data.view.y = max(0, min(data.map.size[1]*32-data.view.scale_h, data.view.y))
 
 
 holding = False
@@ -215,6 +237,8 @@ def handle_events(dt):
     """ Handle input events from pygame. """
     global holding, chatting, chatting_msg
 
+    k = pygame.key.get_pressed()
+
     for event in pygame.event.get():
         if event.type == QUIT:
             sys.exit(0)
@@ -240,6 +264,39 @@ def handle_events(dt):
                 elif event.key == K_RETURN:
                     chatting = True
 
+
+
+                # Group control
+                mods = pygame.key.get_mods()
+                if data.selected_units and (KMOD_LCTRL | KMOD_RCTRL) & mods:
+                    if event.key in nums.keys():
+                        group_num = nums[event.key]
+
+                        # Clear group we are going to assign to.
+                        for u in groups[group_num]:
+                            u.group = None
+
+                        for u in data.selected_units:
+                            # Remove unit from any existing group it belongs to.
+                            if u.group:
+                                groups[u.group].remove(u)
+
+                            u.group = group_num
+
+                        groups[group_num] = data.selected_units.copy()
+
+                # Selecting groups
+                elif event.key in nums.keys():
+                    group = groups[nums[event.key]]
+                    if group:
+                        for u in data.selected_units:
+                            u.selected = False
+                        data.selected_units = group.copy()
+
+                        for u in data.selected_units:
+                            u.selected = True
+                        look_at(u.x*32, u.y*32)
+
             else:
                 handle_chatting(event)
 
@@ -258,16 +315,25 @@ def handle_events(dt):
             handle_mouse_release(event.button)
             holding = False
 
-    k = pygame.key.get_pressed()
     if chatting:
         if data.get_ticks()-last_back_press > 300:
             if k[K_BACKSPACE]:
                 chatting_msg = chatting_msg[:-1]
-                
-    if k[K_PAGEUP]:
-        data.view.zoom = min(data.view.zoom+0.02, 1)
-    elif k[K_PAGEDOWN]:
-        data.view.zoom = max(data.view.zoom-0.02, 0.1)
+
+    if k[K_PAGEUP] or k[K_PAGEDOWN]:
+        cx = (data.view.x+data.view.scale_w/2)
+        cy = (data.view.y+data.view.scale_h/2)
+        if k[K_PAGEUP]:
+            if data.view.zoom != 1:
+                data.view.zoom = min(data.view.zoom+0.02, 1)
+        elif k[K_PAGEDOWN]:
+            if data.view.zoom != 0.1:
+                data.view.zoom = max(data.view.zoom-0.02, 0.1)
+        look_at(cx,cy)
+
+
+
+
 
     scroll_screen(pygame.mouse.get_pos(), dt)
 
