@@ -4,14 +4,31 @@ import itertools
 import textures
 import pygame
 from OpenGL.GL import *
-import glFreeType
+import font
 import settings
 from random import random, randint
 
 import rabbyt
+import os
 
 
 
+def play_menu_music():
+    pygame.mixer.music.load(os.path.join("data", "music", "main_menu.ogg"))
+    pygame.mixer.music.play()
+
+def play_game_music():
+    music = "snowballz2.mp3"
+    if map.config.has_option("map", "music"):
+        music = map.config.get("map", "music")
+    try:
+        pygame.mixer.music.load(os.path.join("data", "music", music))
+    except:
+        pygame.mixer.music.load(os.path.join("data", "music", "snowballz2.mp3"))
+
+    pygame.mixer.music.play(-1)
+
+
 THIS_IS_SERVER = True
 
 
@@ -242,9 +259,7 @@ class Messages:
             first = True
             color = m.from_player.glcolor[:]
             color.append(alpha)
-            glColor4f(*color)
-            chat_font.glPrint(10, view.h-y, m.msg)
-            glColor4f(1,1,1,1)
+            chat_font.render(10, view.h-y, m.msg, color)
             if alpha == 0:
                 to_r = True
             y += h
@@ -283,7 +298,7 @@ class Snowflakes(object):
     def __init__(self):
         self.flakes = set()
 
-        self.max_flakes = 150
+        self.max_flakes = 100
 
         self.bounds = [[0,0],[0,0]]
 
@@ -292,7 +307,7 @@ class Snowflakes(object):
     def run(self, falling):
         self.scheduler.pump()
         if falling:
-            while len(self.flakes) < self.max_flakes:
+            if len(self.flakes) < self.max_flakes:
                 self.add_flake()
 
         # Update the bounds with the view information:
@@ -398,11 +413,28 @@ data_loaded = False
 footprints_settings = 0
 icepinnacle = []
 snowflakes_texture = []
+
+def load_snowflakes():
+    global snowflakes_texture, snowflakes
+    st = textures.Texture("data/snowparticles.png")
+    snowflakes_texture.append(st.sub(0,0,8,8))
+    snowflakes_texture.append(st.sub(8,0,8,8))
+    snowflakes_texture.append(st.sub(0,8,8,8))
+    snowflakes_texture.append(st.sub(8,8,8,8))
+
+    snowflakes = Snowflakes()
+
+def load_font():
+    global chat_font, stat_font
+    # Fonts.
+    chat_font = font.Font("data/TSCu_Comic.ttf", 20)
+    stat_font = font.Font("data/TSCu_Comic.ttf", 16, True)
+
 def init(mapname):
     from player import Player
     from map import Map
     from minimap import MiniMap
-    global data_loaded, penguins, map, player, trees, snowballtextures, smoke, snowparticle, Imprent, snowballimprents, snowball_ice_imprents, footimprents, penguinselection, moveimprents, marker, jeopardy_marker, fish, minimap, units, buildings, resources, snowballs, players, draw_buffer, selected_units, select_box_start, select_box_end, draw_minimap, runmoveimprents, chat_font, stat_font, gathermoveimprents, footprints_settings, icepinnacle, snowflakes_texture, snowflakes
+    global data_loaded, penguins, map, player, trees, snowballtextures, smoke, snowparticle, Imprent, snowballimprents, snowball_ice_imprents, footimprents, penguinselection, moveimprents, marker, jeopardy_marker, fish, minimap, units, buildings, resources, snowballs, players, draw_buffer, selected_units, select_box_start, select_box_end, draw_minimap, runmoveimprents, gathermoveimprents, footprints_settings, icepinnacle
 
     # We cache this here because this option is accessed so often.
     footprints_settings = int(settings.get_option("footprints"))
@@ -430,9 +462,6 @@ def init(mapname):
 
 
     if not data_loaded:
-        # Fonts.
-        chat_font = glFreeType.Font("data/TSCu_Comic.ttf", 20)
-        stat_font = glFreeType.Font("data/TSCu_Comic.ttf", 16, True)
 
         # Some general textures.
         fish = textures.Texture("data/fish.png")
@@ -442,15 +471,6 @@ def init(mapname):
         smoke = textures.Texture("data/smoke.png")
         penguinselection = textures.Texture("data/selected.png")
 
-        # Snowflakes
-        st = textures.Texture("data/snowparticles.png")
-        snowflakes_texture.append(st.sub(0,0,8,8))
-        snowflakes_texture.append(st.sub(8,0,8,8))
-        snowflakes_texture.append(st.sub(0,8,8,8))
-        snowflakes_texture.append(st.sub(8,8,8,8))
-
-        snowflakes = Snowflakes()
-
         # Trees.
         tt = textures.Texture("data/trees.png")
         trees.append(tt.sub(0,0,64,64))
