@@ -129,10 +129,6 @@ def draw(game, dt):
         if cx+64 > data.view.x and cx < data.view.x+vw+64\
                 and cy+64 > data.view.y and cy < data.view.y+vh+64:
             u.draw()
-            #if u in ctrl.selected_enemy_units:
-                #glColor3f(0,0,0)
-                #data.stat_font.glPrint(u.draw_x, u.draw_y+32, u.player.name)
-                #glColor3f(1,1,1)
         else:
             #FIXME: This doesn't work!!!!! :(
             continue
@@ -183,7 +179,7 @@ def draw(game, dt):
     draw_buildings = set()
     for b in data.buildings:
         if b.x*32+256 > data.view.x and b.x*32 < data.view.x+vw\
-                and b.y*32+256 > data.view.y and b.y*32 < data.view.y+vh:
+                and b.y*32+256 > data.view.y and b.y*32 < data.view.y+vh+246:
             b.draw()
             draw_buildings.add(b)
 
@@ -210,17 +206,8 @@ def draw(game, dt):
             data.snowballs.discard(s)
         else:
             # Draw snowball.
-            x = s.x
-            y = s.y
-            glPushMatrix()
-
-            glTranslatef(x, y+8, 0)
-            data.snowballtextures[1].render()
-
-            glTranslatef(0, -s.y_offset, 0)
-            data.snowballtextures[0].render()
-
-            glPopMatrix()
+            s.sprite.render()
+            s.shadow_sprite.render()
 
 
     data.moveimprents.draw(dt)
@@ -291,8 +278,6 @@ def draw(game, dt):
         data.draw_box(0,0,data.view.w,data.view.h)
         glColor4f(1,1,1,1)
 
-    # Draw chat.
-    data.messages.drawall()
 
     if ctrl.chatting:
         glColor4f(0,0,0,0.7)
@@ -304,15 +289,16 @@ def draw(game, dt):
         glEnd()
 
         if ctrl.chatting_help:
-            glColor3f(0.65,0.65,0.65)
-            data.chat_font.glPrint(10, 30, ctrl.chatting_help)
-
-        glColor3f(1,1,1)
-        data.chat_font.glPrint(10, 00, ctrl.chatting_msg+"_")
+            data.chat_font.render(10, 30, ctrl.chatting_help, (0.65,0.65,0.65))
 
+        data.chat_font.render(10, 00, ctrl.chatting_msg+"_")
 
     glEnable(GL_TEXTURE_2D)
 
+    # Draw chat.
+    data.messages.drawall()
+
+
     # Draw select control
     selectctrl.update()
     if selectctrl._display:
