@@ -41,7 +41,7 @@ class Map:
         data.map = map
         z = zipfile.ZipFile(os.path.join("maps", name+".zip"), "r")
         settingsfile = z.read("settings.ini")
-        config = map.config = ConfigParser()
+        map.config = config = ConfigParser()
         config.readfp(StringIO(settingsfile))
 
 
@@ -69,7 +69,7 @@ class Map:
 
         map.size = (rimage.get_width(), rimage.get_height())
 
-        # Regions
+        # Regions and terrain
         map.regions = {}
         for x in range(map.size[0]):
             for y in range(map.size[1]):
