@@ -302,8 +302,9 @@ class MWarmth(Message):
 
 class MSnowball(Message):
     type_id = 105
-    struct_format = "!HIIBHH"
-    attrs = ("unit_id", "x", "y", "snowballs_left", 'px', 'py')
+    struct_format = "!HIIIIHHBHH"
+    attrs = ("unit_id", "start_x", "start_y", "end_x", "end_y", "end_tile_x",
+            "end_tile_y", "snowballs_left", 'px', 'py')
 
 
 class MUnitIglooChange(Message):
@@ -320,8 +321,8 @@ class MBuildingOwner(Message):
 
 class MBuildingJeopardy(Message):
     type_id = 111
-    struct_format = "!HB"
-    attrs = ('building_id', 'jeopardy')
+    struct_format = "!HBH"
+    attrs = ('building_id', 'jeopardy', 'player_taking_over_id')
 
 class MBuildingStorage(Message):
     type_id = 112
@@ -535,8 +536,9 @@ class MasterUnit(Unit):
 
     def throw_snowball(self, target):
         s = Unit.throw_snowball(self, target)
-        send(MSnowball(self.unit_id, s.t_x, s.t_y, self.snowballs,
-                self.x, self.y))
+        send(MSnowball(self.unit_id, s.start_x, s.start_y, s.end_x, s.end_y,
+                s.end_tile.x, s.end_tile.y,
+                self.snowballs, self.x, self.y))
         self._last_state_sent = "throwing"
         return s
 
@@ -567,9 +569,10 @@ class SlaveUnit(Unit):
     def handle_MSnowball(self, m):
         self.snowballs = m.snowballs_left
         #self.current_frame = 1
-        dir = self.direction_to_tile(m.x//32, m.y//32)
+        dir = self.direction_to_tile(m.end_tile_x, m.end_tile_y)
         self._next_position = ((m.px, m.py), dir, "throwing", None)
-        self._next_snowball = (m.x, m.y)
+        end_tile = data.map.tiles[(m.end_tile_x, m.end_tile_y)]
+        self._next_snowball = (m.start_x, m.start_y, m.end_x, m.end_y, end_tile)
 
     def handle_MWarmth(self, m):
         self.warmth = m.warmth
@@ -611,8 +614,7 @@ class SlaveUnit(Unit):
                 if self.state == "throwing" and self._next_snowball:
                     # We need to throw a snowball!
                     self.current_frame = 1
-                    data.snowballs.add(snowball.Snowball(self.x*32, self.y*32,
-                            *self._next_snowball))
+                    data.snowballs.add(snowball.Snowball(*self._next_snowball))
                     self._next_snowball = None
                     self.moving = False
                     if self.snowballs == 0:
@@ -640,7 +642,8 @@ class MasterIgloo(Igloo):
     def _set_jeopardy(self, j):
         self._jeopardy = j
         if hasattr(self, 'building_id'):
-            send(MBuildingJeopardy(self.building_id, j))
+            send(MBuildingJeopardy(self.building_id, j, 
+                    self.player_taking_over.player_id))
     jeopardy = property((lambda self:self._jeopardy), _set_jeopardy)
 
     def storage_changed(self):
@@ -661,6 +664,8 @@ class SlaveIgloo(Igloo):
 
     def handle_MBuildingJeopardy(self, m):
         self.jeopardy = bool(m.jeopardy)
+	self.player_taking_over = data.players[m.player_taking_over_id]
+	self.jeopardy_count = data.get_ticks()
 
     def handle_MBuildingStorage(self, m):
         self._storage['fish'] = m.fish
