@@ -37,7 +37,7 @@ class GatherVictoryPlugin(object):
             amount = 0
             for b in data.buildings:
                 if b.player == penguin.player:
-                    amount += b.storage[self.resource_type]
+                    amount += b.num_storage(self.resource_type)
 
             if amount >= self.amount:
                 for p in data.players.values():
