@@ -50,8 +50,9 @@ class Snowball:
         Starts the snowball with being thrown as a specified target, with
         random accuracy.
         """
-        x, y = penguin.x*32, penguin.y*32
 
+
+        # t_x_t stands for "tile x target".
         if penguin.x <= target_penguin.x + 3 and penguin.x >= target_penguin.x - 3\
         and penguin.y <= target_penguin.y + 3 and penguin.y >= target_penguin.y - 3:
             t_x_t = target_penguin.x
@@ -61,37 +62,50 @@ class Snowball:
             t_y_t = random.randint(target_penguin.y-1,target_penguin.y+1)
 
         end_tile = data.map.tiles[(t_x_t, t_y_t)]
-        t_x = t_x_t*32+random.randint(0, 20)
-        t_y = t_y_t*32+random.randint(0, 20) - end_tile.elevation *\
+        end_x = t_x_t*32+random.randint(0, 20)
+        end_y = t_y_t*32+random.randint(0, 20) - end_tile.elevation *\
                 data.map.elevation_multiplier
 
         start_tile = data.map.tiles[(penguin.x, penguin.y)]
-        y -= start_tile.elevation*data.map.elevation_multiplier
+        start_x, start_y = penguin.x*32, penguin.y*32
+        start_y -= start_tile.elevation*data.map.elevation_multiplier
 
-        return cls(x,y,t_x,t_y,start_tile,end_tile,penguin)
+        return cls(start_x,start_y, end_x,end_y,end_tile, start_tile, penguin)
 
 
-    def __init__(self, x, y, t_x ,t_y, start_tile, end_tile, penguin=None):
-        self.start_tile = start_tile
+    def __init__(self, start_x, start_y, end_x, end_y, end_tile,
+            start_tile=None, penguin=None):
+        """ start_x, start_y, end_x and end_y and all pixel based. """
         self.end_tile = end_tile
-        self.x, self.y = self.start_x, self.start_y = x, y
-        self.t_x, self.t_y = t_x, t_y
+
+        # These are only needed for the server (unit code). They arn't sent
+        # over the network.
+        self.start_tile = start_tile
+        self.penguin = penguin
+
+        self.end_x, self.end_y = end_x, end_y
+        self.start_x, self.start_y = start_x, start_y
 
         self.speed = .15
         self.y_offset = 0
 
-        self.dist_x = self.t_x - self.x
-        self.dist_y = self.t_y - self.y
+        self.dist_x = self.end_x - start_x
+        self.dist_y = self.end_y - start_y
 
         self.dist = (self.dist_x**2 + self.dist_y**2)**.5
-        #self.remaining_dist = -self.dist/2
         self.total_time = self.dist/self.speed
 
         self.height = ((self.dist/2)/10)**2
 
         self.start_time = data.get_ticks()
 
-        self.penguin = penguin
+        tex = data.snowballtextures[0]
+        self.sprite = rabbyt.Sprite(tex.texture_id,tex.get_shape_pos(),
+                tex.get_shape_tex(invert_y=True))
+
+        tex = data.snowballtextures[1]
+        self.shadow_sprite = rabbyt.Sprite(tex.texture_id,tex.get_shape_pos(),
+                tex.get_shape_tex(invert_y=True))
 
     def move(self):
         time_diff = data.get_ticks()-self.start_time
@@ -100,11 +114,13 @@ class Snowball:
         mx = (to_move*self.dist_x)/self.dist
         my = (to_move*self.dist_y)/self.dist
 
-        self.x = self.start_x + mx
-        self.y = self.start_y + my
-
         offset = -((to_move-self.dist/2)/10)**2 + self.height
-        self.y_offset = offset/2
+
+        self.sprite.x = self.start_x + mx
+        self.sprite.y = self.start_y + my + 8 - offset/2
+        
+        self.shadow_sprite.x = self.start_x + mx
+        self.shadow_sprite.y = self.start_y + my
 
         if data.get_ticks() - self.start_time >= self.total_time:
             # Snowball reached dest.
@@ -124,12 +140,13 @@ class Snowball:
 
             if hit != 2 and int(settings.get_option("snowballdetail")) >= 2:
                 if self.end_tile.type == "snow":
-                    data.snowballimprents.add(self.x, self.y)
+                    data.snowballimprents.add(self.sprite.x, self.sprite.y)
                 else:
-                    data.snowball_ice_imprents.add(self.x, self.y)
+                    data.snowball_ice_imprents.add(self.sprite.x, self.sprite.y)
 
-            if self.x > data.view.x and self.x < data.view.x+vw\
-                    and self.y > data.view.y and self.y < data.view.y+vh:
+            if self.sprite.x > data.view.x and self.sprite.x < data.view.x+vw\
+                    and self.sprite.y > data.view.y and self.sprite.y <\
+                    data.view.y+vh:
                 d = sqrt(self.dist_y*self.dist_y + self.dist_x*self.dist_x)
                 y = self.dist_y * (30/d)
                 x = self.dist_x * (30/d)
@@ -140,7 +157,8 @@ class Snowball:
                     particles = random.randint(8,10)
 
                 if int(settings.get_option("snowballdetail")) == 3:
-                    data.particles.add(SnowParticles(self.x, self.y, (x,y), particles))
+                    data.particles.add(SnowParticles(self.sprite.x,
+                            self.sprite.y, (x,y), particles))
 
             return True
         return False
