@@ -29,7 +29,6 @@ import menu
 import selectctrl
 
 import data, ctrl, unit
-import glFreeType
 
 import display
 
@@ -135,7 +134,6 @@ class Main:
         self.lobbybg.render(y=60, invert_y=False)
 
         # Draw chat.
-        data.messages.drawall()
         if ctrl.chatting:
             glColor4f(0,0,0,0.75)
             glBegin(GL_QUADS)
@@ -146,20 +144,21 @@ class Main:
             glEnd()
 
             if ctrl.chatting_help:
-                glColor3f(0.65,0.65,0.65)
-                data.chat_font.glPrint(10, 30, ctrl.chatting_help)
+                data.chat_font.render(10, 30, ctrl.chatting_help,
+                        (0.65,0.65,0.65))
 
-            glColor3f(1,1,1)
-            data.chat_font.glPrint(10, 00, ctrl.chatting_msg+"_")
+            data.chat_font.render(10, 00, ctrl.chatting_msg+"_", (1,1,1))
+        data.messages.drawall()
 
 
-        glColor3f(0,0,0)
         if data.THIS_IS_SERVER:
-            data.chat_font.glPrint(self.vw/2 - 200, 20,
-                    "Waiting for connections - Press 'S' to start")
+            data.chat_font.render(self.vw/2 - 200, 20,
+                    "Waiting for connections - Press 'S' to start",
+                    (0,0,0))
         else:
-            data.chat_font.glPrint(self.vw/2 - 230, 20,
-                    "Waiting for more players to join - Press 'Enter' to chat")
+            data.chat_font.render(self.vw/2 - 230, 20,
+                    "Waiting for more players to join - Press 'Enter' to chat",
+                    (0,0,0))
 
         i = 0
         for p in data.players.values():
@@ -170,12 +169,10 @@ class Main:
                 t += " (loading)"
             else: a = 1
             c.append(a)
-            glColor4f(*c)
-            data.chat_font.glPrint(self.vw/2 - 60, 100 + 23*i, t)
+            data.chat_font.render(self.vw/2 - 60, 100 + 23*i, t, c)
 
             i += 1
-        glColor3f(0,0,0)
-        data.chat_font.glPrint(self.vw/2 - 80, 100 + 23*i, "Players:")
+        data.chat_font.render(self.vw/2 - 80, 100 + 23*i, "Players:", (0,0,0))
 
 
         glColor3f(1,1,1)
@@ -193,7 +190,6 @@ class Main:
         self.time = 45
         self.clock = pygame.time.Clock()
         self.running = True
-                # Load data
 
         self.last_ai_tick = 0
         self.last_alert_tile_tick = data.get_ticks()
@@ -201,6 +197,7 @@ class Main:
         self.last_time_tick = data.get_ticks()
         #glScalef(0.5, 0.5, 1)
         #glTranslatef(0, 500,0)
+        data.play_game_music()
         self.run_loop()
 
     def run_loop(self):
@@ -212,6 +209,7 @@ class Main:
             if data.player.victory != None:
                 self.running = False
 
+        pygame.mixer.music.fadeout(1000)
         self.end_game_loop()
 
     def end_game_loop(self):
@@ -294,7 +292,7 @@ class Main:
         if not data.player: return
         for i in data.buildings:
             if i.player == data.player:
-                ctrl.look_at(i.x, i.y)
+                ctrl.look_at(i.x*32, i.y*32)
                 break
 
     def loading_screen(self):
@@ -586,6 +584,9 @@ class ClientMain(Main, NetLoopBase):
         Main.load_data(self, mapname)
 
 
+
+
+
 # Setup display
 if settings.get_option("fullscreen") == "1":
     flags = OPENGL | DOUBLEBUF | FULLSCREEN
@@ -610,10 +611,14 @@ glEnable(GL_BLEND)
 
 data.view.w, data.view.h = viewport
 
+data.load_font()
+data.load_snowflakes()
+
 if len(sys.argv) <= 1:
     mainmenu = menu.Main(viewport)
 while True:
     pygame.mouse.set_visible(True)
+    data.play_menu_music()
     if len(sys.argv) <= 1:
         mapname, gametype, arg = mainmenu.run()
     else:
@@ -631,6 +636,7 @@ while True:
             mapname = sys.argv[2]
 
     #glHint(GL_TEXTURE_COMPRESSION_HINT, GL_FASTEST)
+    pygame.mixer.music.fadeout(3000)
 
     if gametype == "single":
         main = Main()
