@@ -28,7 +28,19 @@ class Unit(object):
     max_warmth = 10
     gather_time = 20000
     create_snowball_time = 3000
-    walk_speed = 800
+
+    @property
+    def walk_speed(self):
+        r = 800
+        np = self.pos_in_dir(self.direction)
+        t = data.map.tiles[(self.x, self.y)]
+        try:
+            t2 = data.map.tiles[np]
+            d = t2.elevation - t.elevation
+        except:
+            d = 0
+        r += d*50
+        return r
 
     def __init__(self, pos, igloo, type, state="inbuilding"):
         self.direction = None
@@ -39,7 +51,11 @@ class Unit(object):
         self.current_frame = randint(0, 10)
         self.last_tick = 0
 
+        # Some client only stuff:
+        self.group = None
         self.selected = False
+
+
         self.type = type
         self.warmth = self.max_warmth
         self.prv_node = None
@@ -48,6 +64,7 @@ class Unit(object):
         self.igloo.units.add(self)
 
         self.target_pos = None
+        self.stray_range = 5
 
         self._go_to_building = None
 
@@ -62,7 +79,6 @@ class Unit(object):
 
 
         self.move_time = 0
-        self.offset = 0
         self.moving = False
 
         # Direction that the unit is moving in
@@ -93,7 +109,8 @@ class Unit(object):
         self._emblems.add(emblem)
 
     def remove_emblem(self, emblem):
-        self._emblems.remove(emblem)
+        if emblem in self._emblems:
+            self._emblems.remove(emblem)
 
     def _set_go_to_building(self, building):
         if self.state != "entering" and (self.state != "inbuilding" or not self._go_to_building):
@@ -102,6 +119,9 @@ class Unit(object):
 
 
     def draw(self):
+        if self.direction == (0,0):
+            print "warnning: direction is (0,0)"
+            self.direction = (0,1)
         x,y = self.penguin_sprite.xy
         self.draw_x = x
         self.draw_y = y
@@ -198,8 +218,13 @@ class Unit(object):
             glEnd()
 
             glColor3f(1,1,1)
+
             glPopMatrix()
 
+        if self.group:
+            data.stat_font.render(self.draw_x, self.draw_y, str(self.group),
+                    (1,1,1,1))
+
 
     def animate(self, dt):
         #TODO: make the rate of penguin walking based on time.
@@ -308,9 +333,7 @@ class Unit(object):
                     self.__fail_time = data.get_ticks()
         else:
             time_passed = data.get_ticks()-self.counter
-            self.offset = int(time_passed/float(self.walk_speed)*32)
-            if self.offset >= 32:
-                self.offset = 0
+            if time_passed/float(self.walk_speed) >= 1:
                 self.check_direction()
 
         endxy = self.x, self.y
@@ -359,10 +382,6 @@ class Unit(object):
 
 
     def find_path(self):
-        if self.offset != 0:
-            # Return if penguin is currently moving.
-            return None
-
         direction = self.stray()
         if not direction:
             return direction
@@ -583,6 +602,8 @@ class Unit(object):
                 self.go_to_building = t.building
         else:
             self.target_pos = pos
+            self.stray_range = len(data.selected_units)/2
+            self.stray_range = min(max(0, self.stray_range), 6)
 
     def check_demand(self, b):
         if b.construction < 100:
@@ -631,8 +652,11 @@ class Unit(object):
         units_in_range = set()
         for u in data.map.unit_nodes.get_objs_around_tile((self.x,self.y)):
             if u.igloo.player is not self.igloo.player:
-                if  not (u.x > self.x+7 or u.x < self.x-7)\
-                and not (u.y > self.y+7 or u.y < self.y-7):
+                t = data.map.tiles[(self.x, self.y)]
+                ot = data.map.tiles[(u.x, u.y)]
+                a = 7 + (t.elevation - ot.elevation)
+                if  not (u.x > self.x+a or u.x < self.x-a)\
+                and not (u.y > self.y+a or u.y < self.y-a):
                     if u.warmth > 0:
                         if u.state != "inbuilding":
                             units_in_range.add(u)
@@ -668,17 +692,14 @@ class Unit(object):
 
     def is_in_range(self, (x,y)):
         in_range = True
-        jrange = 4
-
-        if x <= self.x-jrange:
+        if x < self.x-self.stray_range:
             in_range = False
-        if x >= self.x+jrange:
+        if x > self.x+self.stray_range:
             in_range = False
-        if y <= self.y-jrange:
+        if y < self.y-self.stray_range:
             in_range = False
-        if y >= self.y+jrange:
+        if y > self.y+self.stray_range:
             in_range = False
-
         return in_range
 
 
@@ -760,6 +781,11 @@ class Snowballer(Unit):
                 # snowballs again.
                 self.run_mode = False
 
+                # This way it won't stand still once it reaches destination if
+                # you only told one penguin to go there.
+                if self.stray_range == 1:
+                    self.stray_range = 3
+
                 # Stray around the current job position.
                 self.last_tiles = []
                 will_stray = randint(1,3)
